// ***************************************************************************
// *                                                                         *
// * Borland Builder Demo for Port Poker                                     *
// *                                                                         *
// * Copyright (c) Novatex Research 1999                                     *
// *                                                                         *
// *                                                                         *
// * MainFormUnit.pas                                                        *
// *                                                                         *
// ***************************************************************************
unit MainFormUnit;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ExtCtrls, StdCtrls;

type
  TForm1 = class(TForm)
    StatusGroup: TGroupBox;
    SendByteGroup: TGroupBox;
    Label1: TLabel;
    ValueEdit: TEdit;
    Out: TButton;
    OutOfPaperPanel: TPanel;
    PrinterIsSelectedPanel: TPanel;
    NOErrorPanel: TPanel;
    IRQEnabledPanel: TPanel;
    BusyPanel: TPanel;
    Label2: TLabel;
    Label3: TLabel;
    Label9: TLabel;
    Label10: TLabel;
    Label6: TLabel;
    DisableIRQ: TButton;
    EnableIRQ: TButton;
    GroupBox1: TGroupBox;
    HookIRQ: TButton;
    UnhookIRQ: TButton;
    Label7: TLabel;
    IRQCount: TLabel;
    Timer1: TTimer;
    procedure EnableIRQClick(Sender: TObject);
    procedure HookIRQClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure Timer1Timer(Sender: TObject);
    procedure DisableIRQClick(Sender: TObject);
    procedure UnhookIRQClick(Sender: TObject);
    procedure OutClick(Sender: TObject);
  private
    count: Integer;     // Used to store the number of IRQ messages received.
    attempted: Integer; // Flags if we have attempted to load the driver.
    loaded: Integer;    // Flags if we have loaded the driver.
  public
    { Public declarations }

    // Overloaded windows procedure for this Form.
    procedure WndProc(var Message: TMessage); override;
  end;

var
  Form1: TForm1;

implementation

{$R *.DFM}

const MYMESSAGE=30000;

{$I NodPP000}


// TForm.EnableIRQClick
// --------------------
// Set the IRQ status to enabled
procedure TForm1.EnableIRQClick(Sender: TObject);
begin
     NovPPSetECPIRQStatus(7,1);
end;

// TForm1.HookIRQClick
// -------------------
// Hook IRQ 7 to this window using MYMESSAGE
procedure TForm1.HookIRQClick(Sender: TObject);
begin
     NovPPHookIrq(7,Handle,MYMESSAGE);
end;

// TForm1.WndProc
// --------------
// Windows procedure for form.
procedure TForm1.WndProc(var Message: TMessage);
begin
     if Message.Msg= MyMessage then begin
        // If we have received the IRQ message, add one to count.
        count:=count+1;
     end else begin
         inherited WndProc(Message);
     end;
end;

// TForm1.FormCreate
// -----------------
// Called after the form is created.
procedure TForm1.FormCreate(Sender: TObject);
begin
     count:=0;
     attempted:=0;
     loaded:=0;
     IRQCount.Caption := IntToStr(count);
end;

// SetColour
// ---------
// Called to set the colour of a panel.
procedure SetColour(high: Integer; panel: TPanel);
begin
     if high > 0 then begin
        panel.Color:= clGreen;
     end else begin
         panel.Color:= clBlack;
     end;
end;

// TForm1.Timer1Timer
// ------------------
// Periodically update the lights on the screen - first time, load the driver.
procedure TForm1.Timer1Timer(Sender: TObject);
var
   status: Byte;
begin
     Timer1.Enabled:= false;

     if attempted=0 then begin
        // If we have not previously attempted to load the driver,
        attempted:=1;

        // do so now...
        loaded:= NovPPLoadDriver;
        if loaded=0 then begin
           // Load failed.
           Application.MessageBox('Unable to load device driver.','Load Fail',MB_ICONINFORMATION);
        end;
     end;

     if loaded<>0 then begin
        // If the driver is loaded, set the status lights.
        status:= NovPPInECP(Word($379));

        SetColour(status and $80, BusyPanel);
        SetColour(status and $20, OutOfPaperPanel);
        SetColour(status and $10, PrinterIsSelectedPanel);
        SetColour(status and $08, NoErrorPanel);


        status:= NovPPInECP($37a);
        SetColour(status and 16, IRQEnabledPanel);

        IRQCount.Caption := IntToStr(count);

     end;
     Timer1.Enabled:= true;
end;

// TForm1.DisableIRQClick
// ----------------------
// Set the IRQ status to disabled
procedure TForm1.DisableIRQClick(Sender: TObject);
begin
     NovPPSetECPIRQStatus(7,0);
end;

// TForm1.UnhookIRQClick
// ---------------------
// Unhook IRQ 7 from this window.
procedure TForm1.UnhookIRQClick(Sender: TObject);
begin
     NovPPUnhookIrq(7,Handle);
end;

// TForm1.OutClick
// ---------------
// Send the byte in the edit box to port $378
procedure TForm1.OutClick(Sender: TObject);
begin
     NovPPOutECP($378,StrToInt(ValueEdit.Text));
end;

end.

